# EnergyFlow
![alt-text](https://travis-ci.org/pkomiske/EnergyFlow.svg?branch=master "Travis-CI Build Status")

EnergyFlow is a Python package that computes Energy Flow Polynomials (EFPs) defined in Ref. [1] and implements Energy Flow Networks (EFNs) and Particle Flow Networks (PFNs) defined in Ref. [2].

#### Installation

To install EnergyFlow with pip, simply write:
```sh
pip install energyflow
```

#### Documentation

The documentation is maintained at [https://energyflow.network](https://energyflow.network).

##### References

[1] P. T. Komiske, E. M. Metodiev, and J. Thaler, _Energy Flow Polynomials: A complete linear basis for jet substructure_, _[JHEP __04__ (2018) 013](https://doi.org/10.1007/JHEP04(2018)013)_ [[1712.07124](https://arxiv.org/abs/1712.07124)].

[2] P. T. Komiske, E. M. Metodiev, and J. Thaler, _Energy Flow Networks: Deep Sets for Particle Jets_, [1810.05165](https://arxiv.org/abs/1810.05165).
